==> keyclic_sdk_api-1.28.9.tar.gz: lib/model/organization_pagination.dart <==
part of keyclic_sdk_api.api;

class OrganizationPagination {
  int limit = null;

  int page = null;

  int pages = null;

  int total = null;

  OrganizationCollection embedded = null;

  PaginationLinks links = null;

  OrganizationPagination();

  @override
  String toString() {
    return 'OrganizationPagination[limit=$limit, page=$page, pages=$pages, total=$total, embedded=$embedded, links=$links, ]';
  }

  OrganizationPagination.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    limit = json['limit'];
    page = json['page'];
    pages = json['pages'];
    total = json['total'];
    embedded = new OrganizationCollection.fromJson(json['_embedded']);
    links = new PaginationLinks.fromJson(json['_links']);
  }

  Map<String, dynamic> toJson() {
    return {
      'limit': limit,
      'page': page,
      'pages': pages,
      'total': total,
      'embedded': embedded,
      'links': links
    };
  }

  static List<OrganizationPagination> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<OrganizationPagination>()
        : json
            .map((value) => new OrganizationPagination.fromJson(value))
            .toList();
  }

  static Map<String, OrganizationPagination> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, OrganizationPagination>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new OrganizationPagination.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.39.1.tar.gz: lib/model/organization_pagination.dart <==
part of keyclic_sdk_api.api;

class OrganizationPagination {
  int limit = null;

  int page = null;

  int pages = null;

  int total = null;

  OrganizationCollection embedded = null;

  PaginationLinks links = null;

  OrganizationPagination({
    this.limit,
    this.page,
    this.pages,
    this.total,
    this.embedded,
    this.links,
  });

  @override
  String toString() {
    return 'OrganizationPagination[limit=$limit, page=$page, pages=$pages, total=$total, embedded=$embedded, links=$links, ]';
  }

  OrganizationPagination.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    limit = json['limit'];
    page = json['page'];
    pages = json['pages'];
    total = json['total'];
    embedded = new OrganizationCollection.fromJson(json['_embedded']);
    links = new PaginationLinks.fromJson(json['_links']);
  }

  Map<String, dynamic> toJson() {
    return {
      'limit': limit,
      'page': page,
      'pages': pages,
      'total': total,
      '_embedded': embedded,
      '_links': links,
    };
  }

  static List<OrganizationPagination> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<OrganizationPagination>()
        : json
            .map((value) => new OrganizationPagination.fromJson(value))
            .toList();
  }

  static Map<String, OrganizationPagination> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, OrganizationPagination>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new OrganizationPagination.fromJson(value));
    }
    return map;
  }
}
